JoystickButton — pyqtgraph 0.11.0rc0 documentation

# JoystickButton

class `pyqtgraph.` `JoystickButton`(parent=None)
  `__init__`(parent=None)

    Initialize self. See help(type(self)) for accurate signature.

  `mouseMoveEvent`(self, e: PySide2.QtGui.QMouseEvent)
  `mousePressEvent`(self, e: PySide2.QtGui.QMouseEvent)
  `mouseReleaseEvent`(self, e: PySide2.QtGui.QMouseEvent)
  `paintEvent`(self, arg__1: PySide2.QtGui.QPaintEvent)
  `resizeEvent`(self, event: PySide2.QtGui.QResizeEvent)
  `wheelEvent`(self, event: PySide2.QtGui.QWheelEvent)